<img src="https://static.wikia.nocookie.net/frstarwars/images/e/e4/Logo_Droid_Depot_SWGE.png/revision/latest?cb=20200730141444" align="right" width="150">

# PyDroidDepot

PyDroidDepot is an open-source project that aims to provide Python access to the Starwars Galaxy's Edge droid depot droids. It allows users to manually control their custom built droids using custom applications.

# Supported Droid Types

* R Units 
* B Unit (WIP)
* BD Unit (WIP)

Droids types that are marked as work in progress will function though they may have unexpected behaviour or may be missing functionality.

## Installation

PyDroidDepot can be installed using `pip`, or by downloading the source code and running the `setup.py` script.

### Installing with pip

To install PyDroidDepot using `pip`, simply run:

```
pip install pydroiddepot
```

### Installing from source

To install PyDroidDepot from source, follow these steps:

1. Download the source code from the [GitHub repository](https://github.com/thetestgame/pydroid).
2. Extract the contents of the archive to a directory of your choice.
3. Navigate to the directory containing the `setup.py` script.
4. Run the following command:

```
python setup.py install
```

## Examples

PyDroidDepot comes with a few examples to help users get started. These examples can be found under the `examples` directory in the repository root.

## License
PyDroidDepot is released under the MIT license. See the LICENSE file for more details.
